@@ -39,8 +39,8 @@ class NullHandler(logging.Handler):
 LOG = logging.getLogger("pkgdb2client")
 
 # Add the null handler to top-level logger used by the library
-h = NullHandler()
-LOG.addHandler(h)
+hand = NullHandler()
+LOG.addHandler(hand)
 
 __version__ = pkg_resources.get_distribution('packagedb-cli').version
 PKGDB_URL = r'https://admin.fedoraproject.org/pkgdb/'
@@ -353,7 +353,13 @@ class PkgDB(object):
 
         if response.status_code != 200:
             LOG.debug('full output: {0}'.format(output))
-            raise PkgDBException(output['error'])
+            if output and 'error' in output:
+                raise PkgDBException(output['error'])
+            elif output is None:
+                raise PkgDBException(
+                    'No output returned by %s' % response.url)
+            else:
+                raise PkgDBException(output)
 
         return output
 
@@ -1032,11 +1038,51 @@ class PkgDB(object):
                 'No version information could be retrieved')
         version = version['version']
         output = []
-        for el in version.split('.'):
+        for el_ver in version.split('.'):
             try:
-                el = int(el)
+                el_ver = int(el_ver)
             except ValueError:
                 pass
-            output.append(el)
+            output.append(el_ver)
 
         return tuple(output)
+
+    def get_pending_acls(self, username=None):
+        ''' Return the list of pending ACLs, eventually restricted to the
+        pending ACLs requiring action from the specified user.
+
+        :return: a list of dictionaries describing the pending ACLs
+        :rtype: list
+        :raise PkgDBException: if the API call does not return a http code
+            200.
+
+        Example of data returned
+
+        ::
+            {
+                "pending_acls": [
+                    {
+                        "acl": "approveacls",
+                        "collection": "f21",
+                        "package": "zbar",
+                        "status": "Awaiting Review",
+                        "user": "firemanxbr"
+                    },
+                    {
+                        "acl": "approveacls",
+                        "collection": "master",
+                        "package": "zbar",
+                        "status": "Awaiting Review",
+                        "user": "firemanxbr"
+                    }
+                ],
+                "total_requests_pending": 4255
+            }
+
+        '''
+
+        args = {'format': 'json'}
+        if username is not None:
+            args['username'] = username
+        return self.handle_api_call('/pendingacls', params=args)
+
