@@ -15,23 +15,23 @@
 # license.
 """
 
-from fedora.client import (AccountSystem, AppError, ServerError)
-from bugzilla.rhbugzilla import RHBugzilla
-from pkgdb2client import PkgDB, PkgDBException, __version__
-import pkgdb2client
+from fedora.client import (AppError, ServerError)
+
 import argparse
 import requests
 import logging
 import koji
 import itertools
 
+from pkgdb2client import PkgDB, PkgDBException, __version__
+import pkgdb2client
+import pkgdb2client.utils
+
 
 KOJI_HUB = 'http://koji.fedoraproject.org/kojihub'
-RH_BZ_API = 'https://bugzilla.redhat.com/xmlrpc.cgi'
 
 pkgdbclient = PkgDB('https://admin.fedoraproject.org/pkgdb',
                     login_callback=pkgdb2client.ask_password)
-fasclient = AccountSystem('https://admin.fedoraproject.org/accounts')
 BOLD = "\033[1m"
 RED = "\033[0;31m"
 RESET = "\033[0;0m"
@@ -190,10 +190,17 @@ def setup_parser():
                         help="Gives more info about what's going on")
     parser.add_argument('--debug', action='store_true',
                         help="Outputs bunches of debugging info")
-    parser.add_argument('--test', action='store_true',
-                        help="Uses a test instance instead of the real pkgdb.")
     parser.add_argument('--version', action='version',
                         version='pkgdb-cli %s' % (__version__))
+    parser.add_argument('--insecure', action='store_true', default=False,
+                        help="Tells pkgdb-cli to ignore invalid SSL "
+                        "certificates")
+    parser.add_argument('--pkgdburl',
+                        help="Base url of the pkgdb instance to query.")
+    parser.add_argument('--fasurl',
+                        help="Base url of the FAS instance to query.")
+    parser.add_argument('--bzurl',
+                        help="Base url of the bugzilla instance to query.")
 
     subparsers = parser.add_subparsers(title='actions')
 
@@ -255,7 +262,8 @@ def setup_parser():
         help="List all orphaned and eol'd packages")
     parser_list.add_argument(
         '--user', dest='user', default=None,
-        help="List all the packages of that user <user> has ACLs on")
+        help="List all the packages of that user <user> has ACLs on (should be "
+        "provided after the `list` action)")
     parser_list.add_argument(
         '--poc', action="store_true",
         default=False, dest='poc',
@@ -340,7 +348,7 @@ def setup_parser():
     parser_update.add_argument(
         'user',
         help="FAS username of the person who requested ACL "
-        "on this package")
+        "on this package (should be provided after the `update` action)")
     parser_update.add_argument(
         'branch', default='master', nargs="?",
         help="Branch of the package for which the ACL is "
@@ -365,6 +373,17 @@ def setup_parser():
         help="Return all the branches instead of just the active ones")
     parser_branch.set_defaults(func=do_branch)
 
+    ## Pending ACLS
+    parser_pending = subparsers.add_parser(
+        'pending',
+        help='List the pending ACLs requests')
+    parser_pending.add_argument(
+        'user', default=None, nargs="?",
+        help='Restrict the pending ACLs requests to those requiring action '
+            'from the specified user (should be provided after the `pending` '
+            'action)')
+    parser_pending.set_defaults(func=do_pending)
+
     return parser
 
 
@@ -375,7 +394,6 @@ def do_acl(args):
     LOG.info("package : {0}".format(args.package))
     LOG.info("branch  : {0}".format(args.branch))
     #LOG.info("approve : {0}".format(args.approve))
-    bzclient = RHBugzilla(url=RH_BZ_API)
 
     if args.branch == 'all':
         args.branch = None
@@ -387,9 +405,7 @@ def do_acl(args):
         if args.extra:
             # print the number of opened bugs
             LOG.debug("Query bugzilla")
-            bugbz = bzclient.query(
-                {'bug_status': ['NEW', 'ASSIGNED', 'NEEDINFO'],
-                 'component': args.package})
+            bugbz = pkgdb2client.utils.get_bugz(args.package)
             print "{0} bugs open (new, assigned, needinfo)".format(len(bugbz))
 
     for pkg in sorted(
@@ -588,7 +604,7 @@ def do_orphan(args):
             req = requests.get(dead_url)
             if req.status_code != 200 or not req.text.strip():
                 print 'No `dead.package` for %s on %s, please use '\
-                '`fedpkg retire`' % (pkg_name, pkg_branch)
+                    '`fedpkg retire`' % (pkg_name, pkg_branch)
                 return
         output = pkgdbclient.retire_packages(pkgs, branches)
     else:
@@ -599,6 +615,17 @@ def do_orphan(args):
         print msg
 
 
+def do_pending(args):
+    ''' List pending ACLs requests.
+
+    '''
+    LOG.info("user    : {0}".format(args.user or args.username))
+    output = pkgdbclient.get_pending_acls(args.user or args.username)
+    for msg in output.get('pending_acls'):
+        print '%(user)s requested `%(acl)s` on %(package)s ' \
+            '(%(collection)s)' % msg
+
+
 def do_unorphan(args):
     ''' Unorphan a package in pkgdb.
 
@@ -757,16 +784,26 @@ def main():
     elif arg.verbose:
         LOG.setLevel(logging.INFO)
 
-    if arg.test:
-        global fasclient, pkgdbclient
-        print "Testing environment"
-        fasclient = AccountSystem(
-            'https://admin.stg.fedoraproject.org/accounts',
-            insecure=True)
+    global pkgdbclient
+    if arg.pkgdburl:
+        print "Querying pkgdb at: %s" % arg.pkgdburl
         pkgdbclient = PkgDB(
-            'https://admin.stg.fedoraproject.org/pkgdb',
-            login_callback=pkgdb2client.ask_password,
-            insecure=True)
+            arg.pkgdburl,
+            login_callback=pkgdb2client.ask_password)
+
+    pkgdbclient.insecure = arg.insecure
+
+    if arg.bzurl:
+        if not arg.bzurl.endswith('xmlrpc.cgi'):
+            arg.bzurl = '%s/xmlrpc.cgi' % arg.bzurl
+        print "Querying bugzilla at: %s" % arg.pkgdburl
+        utils.BZCLIENT.url = arg.bzurl
+        utils.BZCLIENT._sslverify = not arg.insecure
+
+    if arg.fasurl:
+        print "Querying FAS at: %s" % arg.pkgdburl
+        utils.FASCLIENT.base_url = arg.fasurl
+        utils.FASCLIENT.insecure = arg.insecure
 
     return_code = 0
 
